@@ -1,8 +1,7 @@
 package File::DataClass::Functions;
 
 use 5.010001;
-use strict;
-use warnings;
+use strictures;
 use feature 'state';
 
 use English               qw( -no_match_vars );
@@ -45,7 +44,7 @@ sub extension_map (;$$) {
    my ($class, $extensions) = @_; state $map //= { '_map_loaded' => 0 };
 
    if (defined $class) {
-      if (defined $extensions) {
+      if (defined $extensions) { # uncoverable branch false
          is_arrayref( $extensions ) or $extensions = [ $extensions ];
 
          for my $extn (@{ $extensions }) {
